import { registerPlugin } from '@capacitor/core';
import { BarcodeScannerResult } from './barcode/BarcodeScannerTypes';
import { BarcodeScannerUiResult, MultipleScanningMode, SingleScanningMode } from './ui_v2/index';
import { mapPlainResult, mapRTUUIResult } from './utils/utils';
/** @internal */
export const ScanbotBarcodeSDKPlugin = registerPlugin('ScanbotBarcodeSDK', {});
export const ScanbotBarcodeSDK = {
    /**
     * Initialize the Scanbot Barcode Scanner SDK with the preferred configuration.
     *
     * @param {ScanbotBarcodeSdkConfiguration} config
     * @returns {Promise<LicenseInfoResult>}
     */
    initializeSdk(config) {
        return ScanbotBarcodeSDKPlugin.initializeSdk(config);
    },
    /**
     * Provides complete information about the current license status.
     *
     * @returns {Promise<LicenseInfoResult>}
     */
    getLicenseInfo() {
        return ScanbotBarcodeSDKPlugin.getLicenseInfo();
    },
    /**
     * Remove all files generated by this plugin.
     *
     * @returns {Promise<string>}
     */
    async cleanup() {
        return ScanbotBarcodeSDKPlugin.cleanup().then((jsResultObject) => mapPlainResult(jsResultObject));
    },
    /**
     * Opens the Ready-To-Use UI screen for scanning barcodes with the desired configuration.
     *
     * @param {BarcodeScannerScreenConfiguration} config
     * @returns {Promise<ResultWrapper<BarcodeScannerUiResult>>}
     */
    async startBarcodeScanner(config) {
        if (config.useCase instanceof SingleScanningMode || config.useCase instanceof MultipleScanningMode) {
            const barcodeItemMapperCallback = config.useCase.barcodeInfoMapping.barcodeItemMapper;
            if (barcodeItemMapperCallback !== null) {
                ScanbotBarcodeSDKPlugin.registerBarcodeItemMapperCallback({}, (barcodeItem) => {
                    const barcodeItemUuid = `${barcodeItem.text}${barcodeItem.upcEanExtension}_${barcodeItem.format}`;
                    barcodeItemMapperCallback(barcodeItem, (barcodeMappedData) => ScanbotBarcodeSDKPlugin.onBarcodeItemMapper({
                        barcodeItemUuid,
                        barcodeMappedData,
                    }), () => ScanbotBarcodeSDKPlugin.onBarcodeItemMapper({
                        barcodeItemUuid,
                    }));
                });
                // On iOS, the communication with the native part is throwing an error (startBarcodeScannerV2) because of the barcodeItemMapper
                // callback in the configuration class (not parsable), that's why we need to remove it before executing startBarcodeScannerV2 method
                config.useCase.barcodeInfoMapping.barcodeItemMapper = null;
            }
        }
        return ScanbotBarcodeSDKPlugin.startBarcodeScanner(config).then((result) => mapRTUUIResult(result, BarcodeScannerUiResult));
    },
    /**
     * Detect barcodes on the image represented by the file URL. The image file URL is part of the input arguments.
     *
     * @param {{imageFileUri: string, configuration: BarcodeScannerConfiguration}} params
     * @returns {Promise<BarcodeScannerResult>}
     */
    async detectBarcodesOnImage(params) {
        return ScanbotBarcodeSDKPlugin.detectBarcodesOnImage(params).then((result) => new BarcodeScannerResult(result));
    },
    /**
     * Extract images from a PDF represented by the file URL. The PDF file URL is part of the input parameters.
     *
     * @param {ExtractImagesFromPdfArguments} params
     * @returns {Promise<string[]>}
     */
    async extractImagesFromPDF(params) {
        return ScanbotBarcodeSDKPlugin.extractImagesFromPDF(params).then((jsResultObject) => mapPlainResult(jsResultObject));
    },
    /**
     * Returns the Base 64 encoded representation of the image data.
     */
    async getImageData(params) {
        return ScanbotBarcodeSDKPlugin.getImageData(params).then((jsResultObject) => mapPlainResult(jsResultObject));
    },
};
export * from './barcode/index';
export * from './base/index';
export * from './documents/index';
export * from './imageRef/index';
export * from './ui_v2/index';
export * from './utils/index';
//# sourceMappingURL=index.js.map