import type { AustraliaPostCustomerFormat, MsiPlesseyChecksumAlgorithm } from '../../barcode/BarcodeConfigurationTypes';
import type { BarcodeDocumentFormat } from '../../barcode/BarcodeDocumentTypes';
import type { BarcodeFormat, Gs1Handling, UpcEanExtensionBehavior } from '../../barcode/BarcodeTypes';
import type { DeepPartial } from '../../utils/utils';
import { PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the scanning behavior.
*/
export declare class CommonBarcodeScannerConfiguration extends PartiallyConstructible {
    /**
      List of document formats to be extracted.
      
      Defaults to all document formats.
      */
    extractedDocumentFormats: BarcodeDocumentFormat[];
    /**
      If `true` and extractedDocumentFormats is not empty, then barcodes that do not decode to one of the accepted document formats will be ignored.
      
      Default is false
      */
    onlyAcceptDocuments: boolean;
    /**
      Filter for extended EAN and UPC barcodes.
      
      Default is ALLOW_ANY
      */
    extensions: UpcEanExtensionBehavior;
    /**
      Regular expression filter for barcode text. If the barcode text does not match the regular expression, it will not be scanned. The default is an empty string (setting is turned off). This option overrides `barcodesExtensionFilter` option.
      
      Default is ""
      */
    barcodesRegexFilter: string;
    /**
      Minimum acceptable value of a result BarcodeItem's sizeScore (between 0 and 1). Barcodes with a sizeScore less than this value will not be scanned. When set to 0, barcodes are returned no matter what their size is.
      
      Default is 0
      */
    minimumSizeScore: number;
    /**
      Optional minimum required text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
      
      Default is 0
      */
    minimumTextLength: number;
    /**
      Optional maximum text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
      
      Default is 0
      */
    maximumTextLength: number;
    /**
      Optional minimum required quiet zone on the barcode. Measured in modules (the smallest bar size on a barcode). The default is 10. NOTE - This feature works on ITF barcodes only.
      
      Default is 10
      */
    minimum1DBarcodesQuietZone: number;
    /**
      If `true`, check digits for UPC, EAN and MSI Plessey codes are removed from the result. Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is `false`.
      
      Default is false
      */
    stripCheckDigits: boolean;
    /**
      If `true`, the optional check digit for IATA_2_OF_5 codes is used in validation. The default is `true`.
      
      Default is true
      */
    useIATA2OF5Checksum: boolean;
    /**
      If `true`, the optional check digit for CODE_11 codes is used in validation. The default is `true`.
      
      Default is true
      */
    useCode11Checksum: boolean;
    /**
      List of accepted barcode symbologies.
      
      Defaults to common types.
      */
    barcodeFormats: BarcodeFormat[];
    /**
      Checksum algorithm used for MSI Plessey barcodes. The default value is MOD_10.
      
      Default is MOD_10
      */
    msiPlesseyChecksumAlgorithm: MsiPlesseyChecksumAlgorithm;
    /**
      The customer format used in AUSTRALIA_POST codes. The default value is ALPHA_NUMERIC.
      
      Default is ALPHA_NUMERIC
      */
    australiaPostCustomerFormat: AustraliaPostCustomerFormat;
    /**
      If `true`, enables a mode that slightly decreases scanning quality and energy consumption. Increases scanning speed. If `false`, the mode is disabled. The default is `false`. Android only.
      
      Default is false
      */
    lowPowerMode: boolean;
    /**
      The expected way of handling GS1_COMPOSITE barcodes.
      
      Default is PARSE
      */
    gs1Handling: Gs1Handling;
    /**
      If `true`, the barcode image is returned in the result.
      
      Default is false
      */
    returnBarcodeImage: boolean;
    /** @param source {@displayType `DeepPartial<CommonBarcodeScannerConfiguration>`} */
    constructor(source?: DeepPartial<CommonBarcodeScannerConfiguration>);
}
