import Foundation
import Capacitor
import ScanbotBarcodeSDKWrapper

@objc(ScanbotBarcodeSDKPlugin)
public class ScanbotBarcodeSDKPlugin: CAPPlugin, CAPBridgedPlugin {
    
    private var barcodeItemMapperPluginCall : CAPPluginCall? = nil
    
    // MARK: - Methods from CAPBridgedPlugin. We use this protocol to avoid creating .h and .m files for exporting swift to objc
    public var identifier: String = "ScanbotBarcodeSDKPlugin"
    
    public var jsName: String = "ScanbotBarcodeSDK"
    
    // Need to define all methods here to be available for the Capacitor web runtime
    public var pluginMethods: [CAPPluginMethod] = [
        CAPPluginMethod(name: "initializeSdk", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "getLicenseInfo", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "detectBarcodesOnImage", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "extractImagesFromPDF", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "cleanup", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "getImageData", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "startBarcodeScanner", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "registerBarcodeItemMapperCallback", returnType: CAPPluginReturnNone),
        CAPPluginMethod(name: "onBarcodeItemMapper", returnType: CAPPluginReturnNone),
        // ImageRefs
        CAPPluginMethod(name: "imageRefSerialize", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefDeserialize", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefFromImageFileUri", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefFromEncodedBuffer", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefClone", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefHibernate", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefClear", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefRelease", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefInfo", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefSaveImage", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefEncodeImage", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "makeSnapshot", returnType: CAPPluginReturnPromise),
        CAPPluginMethod(name: "imageRefReleaseAll", returnType: CAPPluginReturnPromise),
    ];
    
    // MARK: - Public methods
    
    @objc func initializeSdk(_ pluginCall: CAPPluginCall) {
        let configurationAsDictionary = pluginCallOptionsToDictionary(pluginCall)
        
        SBBWrapper.initializeSDK(configuration: configurationAsDictionary,
                                 resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func getLicenseInfo(_ pluginCall: CAPPluginCall) {
        SBBWrapper.getLicenseInfo(resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func detectBarcodesOnImage(_ pluginCall: CAPPluginCall) {
        let configurationAsDictionary = pluginCallOptionsToDictionary(pluginCall)
        
        SBBOperations.detectBarcodesOnImage(optionsConfig: configurationAsDictionary,
                                            resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func extractImagesFromPDF(_ pluginCall: CAPPluginCall) {
        let argsAsDictionary = pluginCallOptionsToDictionary(pluginCall)
        
        SBBOperations.extractImagesFromPDF(optionsConfig: argsAsDictionary,
                                           resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func cleanup(_ pluginCall: CAPPluginCall) {
        SBBWrapper.cleanup(resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func getImageData(_ pluginCall: CAPPluginCall) {
        guard let fileUri = pluginCall.getString("imageFileUri") else {
            pluginCall.reject("Missing required property imageFileUri")
            return
        }
        
        SBBOperations.getImageData(imageFilePath: fileUri, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func startBarcodeScanner(_ pluginCall: CAPPluginCall) {
        
        guard let configuration = self.pluginCallOptionsToString(pluginCall)
        else {
            return
        }
        
        guard let parentVC = getPresentedViewControllerOrReject(pluginCall)
        else {
            return
        }
        
        DispatchQueue.main.async {
            if self.barcodeItemMapperPluginCall != nil {
                
                let pluginResultDelegate = ScanbotBarcodeSDKPluginResultDelegate(pluginCall) {
                    
                    if let safeBarcodeItemMapperPluginCall = self.barcodeItemMapperPluginCall {
                        self.bridge?.releaseCall(safeBarcodeItemMapperPluginCall)
                        self.barcodeItemMapperPluginCall = nil
                    }
                }
                
                SBBRTUUI.startBarcodeScannerV2(parentViewController: parentVC,
                                               configurationString: configuration,
                                               resultDelegate: pluginResultDelegate) { barcodeItem in
                    if let safeBarcodeItemMapperPluginCall = self.barcodeItemMapperPluginCall {
                        safeBarcodeItemMapperPluginCall.resolve(barcodeItem)
                    }
                }
            } else {
                SBBRTUUI.startBarcodeScannerV2(parentViewController: parentVC,
                                               configurationString: configuration,
                                               resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
            }
        }
    }
    
    
    // MARK: - ImageRefs
    
    @objc func imageRefSerialize(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefSerialize(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefDeserialize(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefDeserialize(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefFromImageFileUri(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefFromImageFileUri(path: pluginCall.getString("uri")!, optionsAsDictionary: pluginCall.getObject("options")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefFromEncodedBuffer(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefFromEncodedBuffer(buffer: pluginCall.getString("buffer")!, optionsAsDictionary: pluginCall.getObject("options")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefClone(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefClone(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefHibernate(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefHibernate(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefClear(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefClear(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefRelease(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefRelease(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefInfo(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefInfo(uniqueId: pluginCall.getString("uniqueId")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefSaveImage(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefSaveImage(uniqueId: pluginCall.getString("uniqueId")!, path: pluginCall.getString("path")!, optionsAsDictionary: pluginCall.getObject("options")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefEncodeImage(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefEncodeImage(uniqueId: pluginCall.getString("uniqueId")!, optionsAsDictionary: pluginCall.getObject("options")!, resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func makeSnapshot(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefProfilerSnapshot(resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    @objc func imageRefReleaseAll(_ pluginCall: CAPPluginCall) {
        SBImageRef.imageRefReleaseAll(resultDelegate: ScanbotBarcodeSDKPluginResultDelegate(pluginCall))
    }
    
    
    // MARK: - Helper methods that are used only by us from the plugin middle layer (not exposed to the users)
    
    @objc func registerBarcodeItemMapperCallback(_ pluginCall: CAPPluginCall) {
        pluginCall.keepAlive = true
        barcodeItemMapperPluginCall = pluginCall
    }
    
    @objc func onBarcodeItemMapper(_ call: CAPPluginCall) {
        guard let barcodeUUID = call.options["barcodeItemUuid"] as? String else {
            call.reject("Missing required property barcodeItemUuid")
            return
        }
        
        let barcodeMappedData = call.options["barcodeMappedData"] as? [String: Any]
        
        SBBRTUUI.onBarcodeItemMapper(barcodeItemUUID: barcodeUUID, barcodeMappedDataAsDictionary: barcodeMappedData)
    }
    
    
    // MARK: - Private helper methods
    
    private func pluginCallOptionsToDictionary(_ pluginCall: CAPPluginCall) -> [String: Any] {
        return pluginCall.options as? [String: Any] ?? [:]
    }
    
    private func getPresentedViewControllerOrReject(_ pluginCall: CAPPluginCall) -> UIViewController? {
        guard let presentedVC = self.bridge?.viewController else {
            pluginCall.reject("No active view controller")
            return nil
        }
        
        return presentedVC
    }
    
    private func pluginCallOptionsToString(_ pluginCall: CAPPluginCall) -> String? {
        guard let dict = pluginCall.options as? [String: Any],
              let data = try? JSONSerialization.data(withJSONObject: dict),
              let stringDict = String(data: data, encoding: .utf8) else {
            pluginCall.reject("Invalid scanner configuration was provided")
            return nil
        }
        
        return stringDict
    }
}
